OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Napačno geslo",
    "No user supplied" : "Ni navedenega uporabnika",
    "Authentication error" : "Napaka med overjanjem",
    "Please provide an admin recovery password, otherwise all user data will be lost" : "Podati je treba skrbniško obnovitveno geslo, sicer bodo vsi uporabniški podatki izgubljeni.",
    "Wrong admin recovery password. Please check the password and try again." : "Napačno navedeno skrbniško obnovitveno geslo. Preverite geslo in poskusite znova.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Ozadnji program ne podpira spreminjanja gesla, je pa uspešno posodobljeno uporabniško šifriranje.",
    "Unable to change password" : "Ni mogoče spremeniti gesla",
    "Enabled" : "Omogočeno",
    "Not enabled" : "Ni omogočeno",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "nameščanje in posodabljanje programov prek programske zbirke ali zveznega oblaka",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "A problem occurred, please check your log files (Error: %s)" : "Prišlo je do napake. Preverite dnevniške zapise (napaka: %s).",
    "Migration Completed" : "Selitev je končana",
    "Group already exists." : "Skupina že obstaja.",
    "Unable to add group." : "Ni mogoče dodati skupine",
    "Unable to delete group." : "Ni mogoče izbrisati skupine.",
    "log-level out of allowed range" : "stopnja zapisovanja je izven dovoljenega območja",
    "Saved" : "Shranjeno",
    "test email settings" : "preizkusi nastavitve elektronske pošte",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Med pošiljanjem sporočila se je prišlo do napake. Preverite nastavitve (napaka: %s).",
    "Email sent" : "Elektronska pošta je poslana",
    "You need to set your user email before being able to send test emails." : "Pred preizkusnim pošiljanjem sporočil je treba nastaviti elektronski naslov uporabnika.",
    "Invalid mail address" : "Neveljaven elektronski naslov",
    "A user with that name already exists." : "Uporabnik s tem imenom že obstaja.",
    "Unable to create user." : "Ni mogoče ustvariti uporabnika.",
    "Your %s account was created" : "Račun %s je uspešno ustvarjen.",
    "Unable to delete user." : "Ni mogoče izbrisati uporabnika",
    "Forbidden" : "Dostop je prepovedan",
    "Invalid user" : "Neveljavni podatki uporabnika",
    "Unable to change mail address" : "Ni mogoče spremeniti naslova elektronske pošte.",
    "Email saved" : "Elektronski naslov je shranjen",
    "Your full name has been changed." : "Vaše polno ime je spremenjeno.",
    "Unable to change full name" : "Ni mogoče spremeniti polnega imena",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Security & setup warnings" : "Varnost in namestitvena opozorila",
    "Sharing" : "Souporaba",
    "Server-side encryption" : "Šifriranje na strežniku",
    "External Storage" : "Zunanja podatkovna shramba",
    "Cron" : "Periodično opravilo",
    "Email server" : "Poštni strežnik",
    "Log" : "Dnevnik",
    "Tips & tricks" : "Nasveti in triki",
    "Updates" : "Posodobitve",
    "Couldn't remove app." : "Ni mogoče odstraniti programa.",
    "Language changed" : "Jezik je spremenjen",
    "Invalid request" : "Neveljavna zahteva",
    "Admins can't remove themself from the admin group" : "Skrbnikov ni mogoče odstraniti iz skupine skrbnikov (admin)",
    "Unable to add user to group %s" : "Uporabnika ni mogoče dodati k skupini %s",
    "Unable to remove user from group %s" : "Uporabnika ni mogoče odstraniti iz skupine %s",
    "Couldn't update app." : "Programa ni mogoče posodobiti.",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Ali ste prepričani, da želite dodati \"{domain}\" kot varno domeno?",
    "Add trusted domain" : "Dodaj varno domeno",
    "Migration in progress. Please wait until the migration is finished" : "V teku je selitev. Počakajte, da se zaključi.",
    "Migration started …" : "Selitev je začeta ...",
    "Sending..." : "Poteka pošiljanje ...",
    "Official" : "Uradno",
    "Approved" : "Odobreno",
    "Experimental" : "Preizkusno",
    "All" : "Vsi",
    "No apps found for your version" : "Za to različico ni na voljo noben vstavek",
    "The app will be downloaded from the app store" : "Program bo prejet iz zbirke programov",
    "Update to %s" : "Posodobi na %s",
    "_You have %n app update pending_::_You have %n app updates pending_" : ["Na čakanju je %n posodobitev","Na čakanju sta %n posodobitvi","Na čakanju so %n posodobitve","Na čakanju je %n posodobitev"],
    "Please wait...." : "Počakajte ...",
    "Error while disabling app" : "Napaka onemogočanja programa",
    "Disable" : "Onemogoči",
    "Enable" : "Omogoči",
    "Error while enabling app" : "Napaka omogočanja programa",
    "Error: this app cannot be enabled because it makes the server unstable" : "Napaka: ta aplikacija ne more biti aktivna, ker povzroča nestabilnost strežnika",
    "Error: could not disable broken app" : "Napaka: ni mogoče onemogočiti okvarjenega programa",
    "Error while disabling broken app" : "Napaka onemogočanja okvarjenega programa",
    "Updating...." : "Poteka posodabljanje ...",
    "Error while updating app" : "Prišlo je do napake med posodabljanjem programa.",
    "Updated" : "Posodobljeno",
    "Uninstalling ...." : "Odstranjevanje namestitve ...",
    "Error while uninstalling app" : "Prišlo je do napake med odstranjevanjem programa.",
    "Uninstall" : "Odstrani namestitev",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Vstavek je omogočen, vendar zahteva posodobitev. Samodejno bo izvedena preusmeritev na stran za posodobitev v 5 sekundah.",
    "App update" : "Posodabljanje vstavkov",
    "No apps found for {query}" : "Ni programov, skladnih z nizom \"{query}\".",
    "Disconnect" : "Prekinjeni povezavo",
    "Error while loading browser sessions and device tokens" : "Napaka med nalaganjem brskalnika in ključev naprave",
    "Error while creating device token" : "Napaka med izdelavo ključa naprave",
    "Error while deleting the token" : "Napaka med brisanjem ključa",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Prišlo je do napake. Uvoziti je treba ustrezno ASCII kodirano potrdilo PEM.",
    "Valid until {date}" : "Veljavno do {date}",
    "Delete" : "Izbriši",
    "An error occurred: {message}" : "Prišlo je do napake: {message}",
    "Select a profile picture" : "Izbor slike profila",
    "Very weak password" : "Zelo šibko geslo",
    "Weak password" : "Šibko geslo",
    "So-so password" : "Slabo geslo",
    "Good password" : "Dobro geslo",
    "Strong password" : "Odlično geslo",
    "Groups" : "Skupine",
    "Unable to delete {objName}" : "Ni mogoče izbrisati {objName}",
    "Error creating group: {message}" : "Napaka ustvarjanja skupine: {message}",
    "A valid group name must be provided" : "Navedeno mora biti veljavno ime skupine",
    "deleted {groupName}" : "izbrisano {groupName}",
    "undo" : "razveljavi",
    "no group" : "ni skupine",
    "never" : "nikoli",
    "deleted {userName}" : "izbrisano {userName}",
    "add group" : "dodaj skupino",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Sprememba gesla bo povzročila izgubo podatkov, ker obnova podatkov za tega uporabnika ni na voljo.",
    "A valid username must be provided" : "Navedeno mora biti veljavno uporabniško ime",
    "Error creating user: {message}" : "Napaka ustvarjanja uporabnika: {message}",
    "A valid password must be provided" : "Navedeno mora biti veljavno geslo",
    "A valid email must be provided" : "Naveden mora biti veljaven naslov elektronske pošte.",
    "__language_name__" : "Slovenščina",
    "Unlimited" : "Neomejeno",
    "Personal info" : "Osebni podatki",
    "Sessions" : "Seje",
    "App passwords" : "Gesla aplikacije",
    "Sync clients" : "Uskladi odjemalce",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Vse (podrobnosti, opozorila, hrošče, napake in usodne dogodke)",
    "Info, warnings, errors and fatal issues" : "Podrobnosti, opozorila, napake in usodne dogodke",
    "Warnings, errors and fatal issues" : "Opozorila, napake in usodne dogodke",
    "Errors and fatal issues" : "Napake in usodne dogodke",
    "Fatal issues only" : "Le usodne dogodke",
    "None" : "Brez",
    "Login" : "Prijava",
    "Plain" : "Besedilno",
    "NT LAN Manager" : "Upravljalnik NT LAN",
    "SSL" : "SSL",
    "TLS" : "TLS",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Napako je najverjetneje povzročil predpomnilnik ali pospeševalnik, kot sta Zend OPcache ali eAccelerator.",
    "Your server is running on Microsoft Windows. We highly recommend Linux for optimal user experience." : "Strežnik ownCloud je nameščen v okolju Microsoft Windows. Toplo priporočamo okolje Linux za najboljšo uporabniško izkušnjo.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Manjka modul PHP 'fileinfo'. Priporočljivo je omogočiti ta modul za popolno zaznavanje vrst MIME.",
    "System locale can not be set to a one which supports UTF-8." : "Sistemskih jezikovnih nastavitev ni mogoče nastaviti na možnost, ki podpira nabor UTF-8.",
    "This means that there might be problems with certain characters in file names." : "To pomeni, da se lahko pojavijo napake pri nekaterih znakih v imenih datotek.",
    "All checks passed." : "Vsa preverjanja so uspešno zaključena.",
    "Open documentation" : "Odprta dokumentacija",
    "Allow apps to use the Share API" : "Dovoli programom uporabo vmesnika API souporabe",
    "Allow users to share via link" : "Uporabnikom dovoli omogočanje souporabe s povezavami",
    "Allow public uploads" : "Dovoli javno pošiljanje datotek v oblak",
    "Enforce password protection" : "Vsili zaščito z geslom",
    "Set default expiration date" : "Nastavitev privzetega datuma poteka",
    "Allow users to send mail notification for shared files" : "Dovoli uporabnikom pošiljati obvestila o souporabi datotek po elektronski pošti.",
    "Expire after " : "Preteče po",
    "days" : "dneh",
    "Enforce expiration date" : "Vsili datum preteka",
    "Allow resharing" : "Dovoli nadaljnjo souporabo",
    "Allow sharing with groups" : "Dovoli souporabo s skupinami",
    "Restrict users to only share with users in their groups" : "Uporabnikom dovoli omogočanje souporabe le znotraj njihove skupine",
    "Allow users to send mail notification for shared files to other users" : "Dovoli uporabnikom pošiljanje obvestil o souporabi datotek z drugimi uporabniki.",
    "Exclude groups from sharing" : "Izloči skupine iz souporabe",
    "These groups will still be able to receive shares, but not to initiate them." : "Te skupine lahko sprejemajo mape v souporabo, ne morejo pa souporabe dovoliti",
    "Last cron job execution: %s." : "Zadnje periodično opravilo: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Zadnje periodično opravilo: %s. Nekaj izgleda narobe.",
    "Cron was not executed yet!" : "Periodično opravilo cron še ni zagnano!",
    "Execute one task with each page loaded" : "Izvedi eno nalogo z vsako naloženo stranjo.",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "Datoteka cron.php je vpisana za periodično opravilo webcron za potrditev sklica vsakih 15 minut pri povezavi preko HTTP.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Uporabi storitev periodičnih opravil za klic datoteke cron.php vsakih 15 minut.",
    "Enable server-side encryption" : "Omogoči šifriranje na strežniku",
    "Please read carefully before activating server-side encryption: " : "Pozorno preberite opombe, preden omogočite strežniško šifriranje:",
    "Be aware that encryption always increases the file size." : "Upoštevajte, da šifriranje vedno poveča velikost datoteke.",
    "This is the final warning: Do you really want to enable encryption?" : "To je zadnje opozorilo. Ali resnično želite vključiti šifriranje?",
    "Enable encryption" : "Omogoči šifriranje",
    "Select default encryption module:" : "Izbor privzetega modula za šifriranje:",
    "Start migration" : "Začni selitev",
    "This is used for sending out notifications." : "Možnost je uporabljena za omogočanje pošiljanja obvestil.",
    "Send mode" : "Način pošiljanja",
    "Encryption" : "Šifriranje",
    "From address" : "Naslov pošiljatelja",
    "mail" : "pošta",
    "Authentication method" : "Način overitve",
    "Authentication required" : "Zahtevana je overitev",
    "Server address" : "Naslov strežnika",
    "Port" : "Vrata",
    "Credentials" : "Poverila",
    "SMTP Username" : "Uporabniško ime SMTP",
    "SMTP Password" : "Geslo SMTP",
    "Store credentials" : "Shrani poverila",
    "Test email settings" : "Preizkus nastavitev elektronske pošte",
    "Send email" : "Pošlji elektronsko sporočilo",
    "Download logfile" : "Prejmi dnevniško datoteko",
    "More" : "Več",
    "Less" : "Manj",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Dnevniškega datoteka je večja od 100 MB. Hitrost prejema je odvisna od širokopasovne povezave!",
    "What to log" : "Kaj naj se beleži?",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "Uporabljena zbirka je SQLite. Za obsežnejše sisteme je priporočljiv prehod na drugo vrsto zbirke.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Uporaba SQLite ni priporočljiva iz varnostnih razlogov, to še posebej velja, če se sistem krajevno usklajuje z namizjem prek odjemalca.",
    "How to do backups" : "Kako ustvariti varnostne kopije",
    "Advanced monitoring" : "Napredno sledenje",
    "Performance tuning" : "Prilagajanje delovanja",
    "Improving the config.php" : "Izboljšave v config.php",
    "Theming" : "Teme",
    "Hardening and security guidance" : "Varnost in varnostni napotki",
    "Version" : "Različica",
    "Developer documentation" : "Dokumentacija za razvijalce",
    "Experimental applications ahead" : "Preizkusni programi",
    "%s-licensed" : "dovoljenje-%s",
    "Documentation:" : "Dokumentacija:",
    "User documentation" : "Uporabniška dokumentacija",
    "Admin documentation" : "Skrbniška dokumentacija",
    "Visit website" : "Obiščite spletno stran",
    "Report a bug" : "Pošlji poročilo o hrošču",
    "Show description …" : "Pokaži opis ...",
    "Hide description …" : "Skrij opis ...",
    "This app has an update available." : "Za program so na voljo posodobitve.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Programa ni mogoče namestiti zaradi nerešenih odvisnosti:",
    "Enable only for specific groups" : "Omogoči le za posamezne skupine",
    "Uninstall App" : "Odstrani program",
    "Enable experimental apps" : "Omogoči preizkusne programe",
    "SSL Root Certificates" : "Korenska potrdila SSL",
    "Common Name" : "Splošno ime",
    "Valid until" : "Veljavno do",
    "Issued By" : "Izdajatelj",
    "Valid until %s" : "Veljavno do %s",
    "Import root certificate" : "Uvozi korensko potrdilo",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Pozdravljeni,<br><br>obveščamo vas, da je račun %s pripravljen.<br><br>Uporabniško ime: %s<br>Dostop: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Lep pozdrav!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Pozdravljeni,\n\nobveščamo vas, da je račun %s pripravljen.\n\nUporabniško ime: %s\nDostop: %s\n",
    "Administrator documentation" : "Skrbniška dokumentacija",
    "Online documentation" : "Spletna dokumentacija",
    "Forum" : "Forum",
    "Issue tracker" : "Sledilnih zahtevkov",
    "Commercial support" : "Podpora strankam",
    "You are using <strong>%s</strong> of <strong>%s</strong>" : "Uporabljate <strong>%s</strong> od <strong>%s</strong>",
    "Profile picture" : "Slika profila",
    "Upload new" : "Pošlji novo",
    "Select from Files" : "Izbor iz datotek",
    "Remove image" : "Odstrani sliko",
    "png or jpg, max. 20 MB" : "png ali jpg, največ. 20 MB",
    "Picture provided by original account" : "Slika iz izvornega računa",
    "Cancel" : "Prekliči",
    "Choose as profile picture" : "Izberi kot sliko profila",
    "Full name" : "Polno ime",
    "No display name set" : "Prikazno ime ni nastavljeno",
    "Email" : "Elektronski naslov",
    "Your email address" : "Osebni elektronski naslov",
    "For password recovery and notifications" : "Za obnovo gesla in obveščanje",
    "No email address set" : "Poštni naslov ni nastavljen",
    "You are member of the following groups:" : "Ste član naslednjih skupin:",
    "Password" : "Geslo",
    "Unable to change your password" : "Gesla ni mogoče spremeniti.",
    "Current password" : "Trenutno geslo",
    "New password" : "Novo geslo",
    "Change password" : "Spremeni geslo",
    "Language" : "Jezik",
    "Help translate" : "Sodelujte pri prevajanju",
    "Browser" : "Brskalnik",
    "Most recent activity" : "Zadnja dejavnost",
    "You've linked these apps." : "Vi ste povezali te aplikacije.",
    "Name" : "Ime",
    "App name" : "Naziv aplikacije",
    "Create new app password" : "Ustvari novo geslo aplikacije",
    "Username" : "Uporabniško ime",
    "Done" : "Končano",
    "Get the apps to sync your files" : "Pridobi programe za usklajevanje datotek",
    "Desktop client" : "Namizni odjemalec",
    "Android app" : "Program za Android",
    "iOS app" : "Program za iOS",
    "If you want to support the project\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\tor\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Če želite podpreti projekt\n\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">se pridružite razvijalcem</a>\n\t\tali pa le\n\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">razširite dober glas</a>!",
    "Show First Run Wizard again" : "Zaženi čarovnika prvega zagona",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Programski paket razvija {communityopen}skupnost ownCloud{linkclose}, {githubopen}izvorna koda{linkclose} pa je objavljena z dovoljenjem {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Show storage location" : "Pokaži mesto shrambe",
    "Show last log in" : "Pokaži podatke zadnje prijave",
    "Show user backend" : "Pokaži ozadnji program",
    "Send email to new user" : "Pošlji sporočilo novemu uporabniku",
    "Show email address" : "Pokaži naslov elektronske pošte",
    "E-Mail" : "Elektronska pošta",
    "Create" : "Ustvari",
    "Admin Recovery Password" : "Obnovitev skrbniškega gesla",
    "Enter the recovery password in order to recover the users files during password change" : "Vnesite geslo, ki omogoča obnovitev uporabniških datotek med spreminjanjem gesla",
    "Add Group" : "Dodaj skupino",
    "Group" : "Skupina",
    "Everyone" : "Vsi",
    "Admins" : "Skrbniki",
    "Default Quota" : "Privzeta količinska omejitev",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Vnesite količinsko omejitev prostora (na primer: \"512 MB\" ali \"12 GB\")",
    "Other" : "Drugo",
    "Full Name" : "Polno ime",
    "Group Admin for" : "Skrbnik skupine za",
    "Quota" : "Količinska omejitev",
    "Storage Location" : "Mesto shrambe",
    "User Backend" : "Uporabniški ozadnji program",
    "Last Login" : "Zadnja prijava",
    "change full name" : "Spremeni polno ime",
    "set new password" : "nastavi novo geslo",
    "change email address" : "spremeni naslov elektronske pošte",
    "Default" : "Privzeto"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
